@@ -37,7 +37,7 @@
  *
  * @since 1.15
  */
-EAPI const char *eina_environment_home_get(void);
+EINA_API const char *eina_environment_home_get(void);
 
 /**
  * @brief Returns the content of the environment referred as TMPDIR on this system.
@@ -48,12 +48,12 @@ EAPI const char *eina_environment_home_get(void);
  *
  * @since 1.15
  */
-EAPI const char *eina_environment_tmp_get(void);
+EINA_API const char *eina_environment_tmp_get(void);
 
 /**
  * @brief Warningless comparison of doubles using ==
- * @param a First member to compare
- * @param b Second member to compare
+ * @param[in] a First member to compare
+ * @param[in] b Second member to compare
  *
  * @return @c true if two doubles match
  * @since 1.19
@@ -62,8 +62,8 @@ static inline Eina_Bool eina_dbl_exact(double a, double b);
 
 /**
  * @brief Warningless comparison of floats using ==
- * @param a First member to compare
- * @param b Second member to compare
+ * @param[in] a First member to compare
+ * @param[in] b Second member to compare
  *
  * @return @c true if two floats match
  * @since 1.19
@@ -72,17 +72,17 @@ static inline Eina_Bool eina_flt_exact(float a, float b);
 
 /**
  * @brief Safe comparison of float
- * @param a First member to compare
- * @param b Second member to compare
+ * @param[in] a First member to compare
+ * @param[in] b Second member to compare
  * @since 1.19
  *
  * @return @c true if two floats match
  */
-#define EINA_FLT_EQ(a, b) (!!(fabsf((float)a - (float)b) <= FLT_EPSILON))
+#define EINA_FLT_EQ(a, b) (!!(fabsf((float)(a) - (float)(b)) <= FLT_EPSILON))
 
 /**
  * @brief Determines if a float is not zero
- * @param a The float
+ * @param[in] a The float
  *
  * @return @c true if float is not zero
  * @since 1.19
@@ -91,17 +91,17 @@ static inline Eina_Bool eina_flt_exact(float a, float b);
 
 /**
  * @brief Safe comparison of double
- * @param a First member to compare
- * @param b Second member to compare
+ * @param[in] a First member to compare
+ * @param[in] b Second member to compare
  * @since 1.19
  *
  * @return @c true if two double match
  */
-#define EINA_DBL_EQ(a, b) (!!(fabs((double)a - (double)b) <= DBL_EPSILON))
+#define EINA_DBL_EQ(a, b) (!!(fabs((double)(a) - (double)(b)) <= DBL_EPSILON))
 
 /**
  * @brief Determines if a double is not zero
- * @param a The double
+ * @param[in] a The double
  *
  * @return @c true if double is not zero
  * @since 1.19
