@@ -40,7 +40,7 @@ typedef Eo Efl_Canvas_Animation;
  */
 #define EFL_CANVAS_ANIMATION_CLASS efl_canvas_animation_class_get()
 
-EWAPI const Efl_Class *efl_canvas_animation_class_get(void);
+EVAS_API EVAS_API_WEAK const Efl_Class *efl_canvas_animation_class_get(void) EINA_CONST;
 
 /**
  * @brief If @c true the last mapping state the animation applies will be kept.
@@ -59,7 +59,7 @@ EWAPI const Efl_Class *efl_canvas_animation_class_get(void);
  *
  * @ingroup Efl_Canvas_Animation
  */
-EOAPI void efl_animation_final_state_keep_set(Eo *obj, Eina_Bool keep);
+EVAS_API EVAS_API_WEAK void efl_animation_final_state_keep_set(Eo *obj, Eina_Bool keep);
 
 /**
  * @brief If @c true the last mapping state the animation applies will be kept.
@@ -79,7 +79,7 @@ EOAPI void efl_animation_final_state_keep_set(Eo *obj, Eina_Bool keep);
  *
  * @ingroup Efl_Canvas_Animation
  */
-EOAPI Eina_Bool efl_animation_final_state_keep_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Eina_Bool efl_animation_final_state_keep_get(const Eo *obj);
 
 /**
  * @brief The duration of a single animation "run". The
@@ -94,7 +94,7 @@ EOAPI Eina_Bool efl_animation_final_state_keep_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Animation
  */
-EOAPI void efl_animation_duration_set(Eo *obj, double sec);
+EVAS_API EVAS_API_WEAK void efl_animation_duration_set(Eo *obj, double sec);
 
 /**
  * @brief The duration of a single animation "run". The
@@ -110,7 +110,7 @@ EOAPI void efl_animation_duration_set(Eo *obj, double sec);
  *
  * @ingroup Efl_Canvas_Animation
  */
-EOAPI double efl_animation_duration_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK double efl_animation_duration_get(const Eo *obj);
 
 /**
  * @brief What to do when the animation finishes.
@@ -122,7 +122,7 @@ EOAPI double efl_animation_duration_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Animation
  */
-EOAPI void efl_animation_repeat_mode_set(Eo *obj, Efl_Canvas_Animation_Repeat_Mode mode);
+EVAS_API EVAS_API_WEAK void efl_animation_repeat_mode_set(Eo *obj, Efl_Canvas_Animation_Repeat_Mode mode);
 
 /**
  * @brief What to do when the animation finishes.
@@ -135,7 +135,7 @@ EOAPI void efl_animation_repeat_mode_set(Eo *obj, Efl_Canvas_Animation_Repeat_Mo
  *
  * @ingroup Efl_Canvas_Animation
  */
-EOAPI Efl_Canvas_Animation_Repeat_Mode efl_animation_repeat_mode_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Efl_Canvas_Animation_Repeat_Mode efl_animation_repeat_mode_get(const Eo *obj);
 
 /**
  * @brief How many times to play an animation. <tt>1</tt> means that the
@@ -152,7 +152,7 @@ EOAPI Efl_Canvas_Animation_Repeat_Mode efl_animation_repeat_mode_get(const Eo *o
  *
  * @ingroup Efl_Canvas_Animation
  */
-EOAPI void efl_animation_play_count_set(Eo *obj, int count);
+EVAS_API EVAS_API_WEAK void efl_animation_play_count_set(Eo *obj, int count);
 
 /**
  * @brief How many times to play an animation. <tt>1</tt> means that the
@@ -170,7 +170,7 @@ EOAPI void efl_animation_play_count_set(Eo *obj, int count);
  *
  * @ingroup Efl_Canvas_Animation
  */
-EOAPI int efl_animation_play_count_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK int efl_animation_play_count_get(const Eo *obj);
 
 /**
  * @brief The time that passes since the animation is started and the first
@@ -183,7 +183,7 @@ EOAPI int efl_animation_play_count_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Animation
  */
-EOAPI void efl_animation_start_delay_set(Eo *obj, double sec);
+EVAS_API EVAS_API_WEAK void efl_animation_start_delay_set(Eo *obj, double sec);
 
 /**
  * @brief The time that passes since the animation is started and the first
@@ -197,7 +197,7 @@ EOAPI void efl_animation_start_delay_set(Eo *obj, double sec);
  *
  * @ingroup Efl_Canvas_Animation
  */
-EOAPI double efl_animation_start_delay_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK double efl_animation_start_delay_get(const Eo *obj);
 
 /**
  * @brief Optional mapping function.
@@ -215,7 +215,7 @@ EOAPI double efl_animation_start_delay_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Animation
  */
-EOAPI void efl_animation_interpolator_set(Eo *obj, Efl_Interpolator *interpolator);
+EVAS_API EVAS_API_WEAK void efl_animation_interpolator_set(Eo *obj, Efl_Interpolator *interpolator);
 
 /**
  * @brief Optional mapping function.
@@ -233,7 +233,7 @@ EOAPI void efl_animation_interpolator_set(Eo *obj, Efl_Interpolator *interpolato
  *
  * @ingroup Efl_Canvas_Animation
  */
-EOAPI Efl_Interpolator *efl_animation_interpolator_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK Efl_Interpolator *efl_animation_interpolator_get(const Eo *obj);
 
 /**
  * @brief Overwrite this method to implement your own animation subclasses.
@@ -257,7 +257,7 @@ EOAPI Efl_Interpolator *efl_animation_interpolator_get(const Eo *obj);
  *
  * @ingroup Efl_Canvas_Animation
  */
-EOAPI double efl_animation_apply(Eo *obj, double progress, Efl_Canvas_Object *target);
+EVAS_API EVAS_API_WEAK double efl_animation_apply(Eo *obj, double progress, Efl_Canvas_Object *target);
 
 /**
  * @brief Duration that will be used by default on all animations unless
@@ -269,7 +269,7 @@ EOAPI double efl_animation_apply(Eo *obj, double progress, Efl_Canvas_Object *ta
  *
  * @ingroup Efl_Canvas_Animation
  */
-EOAPI void efl_animation_default_duration_set(double animation_time);
+EVAS_API EVAS_API_WEAK void efl_animation_default_duration_set(double animation_time);
 
 /**
  * @brief Duration that will be used by default on all animations unless
@@ -281,6 +281,6 @@ EOAPI void efl_animation_default_duration_set(double animation_time);
  *
  * @ingroup Efl_Canvas_Animation
  */
-EOAPI double efl_animation_default_duration_get(void);
+EVAS_API EVAS_API_WEAK double efl_animation_default_duration_get(void);
 
 #endif
