@@ -78,7 +78,7 @@ typedef struct _Efl_Canvas_Filter_State
  */
 #define EFL_CANVAS_FILTER_INTERNAL_MIXIN efl_canvas_filter_internal_mixin_get()
 
-EWAPI const Efl_Class *efl_canvas_filter_internal_mixin_get(void);
+EVAS_API EVAS_API_WEAK const Efl_Class *efl_canvas_filter_internal_mixin_get(void) EINA_CONST;
 
 #ifdef EFL_CANVAS_FILTER_INTERNAL_PROTECTED
 /**
@@ -89,7 +89,7 @@ EWAPI const Efl_Class *efl_canvas_filter_internal_mixin_get(void);
  *
  * @ingroup Efl_Canvas_Filter_Internal
  */
-EOAPI void evas_filter_changed_set(Eo *obj, Eina_Bool val);
+EVAS_API EVAS_API_WEAK void evas_filter_changed_set(Eo *obj, Eina_Bool val);
 #endif
 
 #ifdef EFL_CANVAS_FILTER_INTERNAL_PROTECTED
@@ -101,7 +101,7 @@ EOAPI void evas_filter_changed_set(Eo *obj, Eina_Bool val);
  *
  * @ingroup Efl_Canvas_Filter_Internal
  */
-EOAPI void evas_filter_invalid_set(Eo *obj, Eina_Bool val);
+EVAS_API EVAS_API_WEAK void evas_filter_invalid_set(Eo *obj, Eina_Bool val);
 #endif
 
 #ifdef EFL_CANVAS_FILTER_INTERNAL_PROTECTED
@@ -115,7 +115,7 @@ EOAPI void evas_filter_invalid_set(Eo *obj, Eina_Bool val);
  *
  * @ingroup Efl_Canvas_Filter_Internal
  */
-EOAPI Eina_Bool evas_filter_input_alpha(Eo *obj);
+EVAS_API EVAS_API_WEAK Eina_Bool evas_filter_input_alpha(Eo *obj);
 #endif
 
 #ifdef EFL_CANVAS_FILTER_INTERNAL_PROTECTED
@@ -129,7 +129,7 @@ EOAPI Eina_Bool evas_filter_input_alpha(Eo *obj);
  *
  * @ingroup Efl_Canvas_Filter_Internal
  */
-EOAPI void evas_filter_state_prepare(Eo *obj, Efl_Canvas_Filter_State *state, void *data);
+EVAS_API EVAS_API_WEAK void evas_filter_state_prepare(Eo *obj, Efl_Canvas_Filter_State *state, void *data);
 #endif
 
 #ifdef EFL_CANVAS_FILTER_INTERNAL_PROTECTED
@@ -156,7 +156,7 @@ EOAPI void evas_filter_state_prepare(Eo *obj, Efl_Canvas_Filter_State *state, vo
  *
  * @ingroup Efl_Canvas_Filter_Internal
  */
-EOAPI Eina_Bool evas_filter_input_render(Eo *obj, void *filter, void *engine, void *output, void *drawctx, void *data, int l, int r, int t, int b, int x, int y, Eina_Bool do_async);
+EVAS_API EVAS_API_WEAK Eina_Bool evas_filter_input_render(Eo *obj, void *filter, void *engine, void *output, void *drawctx, void *data, int l, int r, int t, int b, int x, int y, Eina_Bool do_async);
 #endif
 
 #ifdef EFL_CANVAS_FILTER_INTERNAL_PROTECTED
@@ -168,7 +168,7 @@ EOAPI Eina_Bool evas_filter_input_render(Eo *obj, void *filter, void *engine, vo
  *
  * @ingroup Efl_Canvas_Filter_Internal
  */
-EOAPI void evas_filter_dirty(Eo *obj);
+EVAS_API EVAS_API_WEAK void evas_filter_dirty(Eo *obj);
 #endif
 
 #ifdef EFL_CANVAS_FILTER_INTERNAL_PROTECTED
@@ -183,7 +183,7 @@ EOAPI void evas_filter_dirty(Eo *obj);
  *
  * @ingroup Efl_Canvas_Filter_Internal
  */
-EOAPI void *evas_filter_output_buffer_get(const Eo *obj);
+EVAS_API EVAS_API_WEAK void *evas_filter_output_buffer_get(const Eo *obj);
 #endif
 #endif /* EFL_BETA_API_SUPPORT */
 
